@@ -26,9 +26,12 @@ SSH = R6::R6Class("SSH",
             system(ssh_cmd, wait=TRUE, ignore.stdout=TRUE, ignore.stderr=TRUE)
 
             # Exchange init messages with proxy
-            poll = rzmq::poll.socket(list(private$proxy_socket), list("read"), timeout=5)
+            init_timeout = getOption("clustermq.ssh.timeout", 5)
+            poll = rzmq::poll.socket(list(private$proxy_socket), list("read"),
+                                     timeout=init_timeout)
             if (!poll[[1]]$read)
-                stop("Remote R process did not respond after 5 seconds. ",
+                stop("Remote R process did not respond after ",
+                     init_timeout, " seconds. ",
                      "Check your SSH server log.")
             msg = rzmq::receive.socket(private$proxy_socket)
             if (msg$id != "PROXY_UP")
